BioData class

Annotations
  • @freezed

Constructors

BioData({Name? firstName, Name? lastName, String? dateOfBirth, Gender? gender})
factory
BioData.fromJson(Map<String, dynamic> json)
factory
BioData.initial()
factory

Properties

copyWith → $BioDataCopyWith<BioData>
no setterinherited
dateOfBirth String?
no setterinherited
firstName Name?
no setterinherited
gender Gender?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
lastName Name?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited