Cover class

Annotations
  • @freezed

Constructors

Cover({String? payerName, int? payerSladeCode, String? memberNumber, String? memberName, String? validTo, String? validFrom})
factory
Cover.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $CoverCopyWith<Cover>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
memberName String?
no setterinherited
memberNumber String?
no setterinherited
payerName String?
no setterinherited
payerSladeCode int?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validFrom String?
no setterinherited
validTo String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited