Customer class

Annotations
  • @freezed

Constructors

Customer({String? id, String? profileID, String? customerID, ReceivablesAccount? receivablesAccount, bool? active})
factory
Customer.fromJson(Map<String, dynamic> json)
factory

Properties

active bool?
no setterinherited
copyWith → $CustomerCopyWith<Customer>
no setterinherited
customerID String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String?
no setterinherited
profileID String?
no setterinherited
receivablesAccount ReceivablesAccount?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited