UserProfile class
UserProfile represents a valid user as mapped out from the backend In the event the backend mapping changes, this model should also change as well
- Annotations
-
- @freezed
Constructors
-
UserProfile({String? id, Name? username, PhoneNumber? primaryPhoneNumber, EmailAddress? primaryEmailAddress, List<
PhoneNumber> ? secondaryPhoneNumbers, List<EmailAddress> ? secondaryEmailAddresses, bool? termsAccepted, bool? suspended, String? photoUploadID, List<Cover?> ? covers, BioData? userBioData, Address? homeAddress, Address? workAddress, String? referralLink, Assistant? assistant}) -
factory
-
UserProfile.fromJson(Map<
String, dynamic> json) -
factory
- UserProfile.initial()
-
factory
Properties
- assistant → Assistant?
-
assistantrefers to the name of the Be.Well user assistant, i.e Bev or Bowi.no setterinherited -
copyWith
→ $UserProfileCopyWith<
UserProfile> -
no setterinherited
-
covers
→ List<
Cover?> ? -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- homeAddress → Address?
-
no setterinherited
- id → String?
-
no setterinherited
- photoUploadID → String?
-
no setterinherited
- primaryEmailAddress → EmailAddress?
-
no setterinherited
- primaryPhoneNumber → PhoneNumber?
-
no setterinherited
- referralLink → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
secondaryEmailAddresses
→ List<
EmailAddress> ? -
no setterinherited
-
secondaryPhoneNumbers
→ List<
PhoneNumber> ? -
no setterinherited
- suspended → bool?
-
no setterinherited
- termsAccepted → bool?
-
no setterinherited
- userBioData → BioData?
-
no setterinherited
- username → Name?
-
no setterinherited
- workAddress → Address?
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited