UserResponse class

Annotations
  • @freezed

Constructors

UserResponse({UserProfile? profile, SupplierProfile? supplierProfile, Customer? customerProfile, CommunicationSettings? communicationSettings, AuthCredentialResponse? auth, Navigation? navigation})
factory
UserResponse.fromJson(Map<String, dynamic> json)
factory

Properties

auth AuthCredentialResponse?
no setterinherited
communicationSettings CommunicationSettings?
no setterinherited
copyWith → $UserResponseCopyWith<UserResponse>
no setterinherited
customerProfile Customer?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
no setterinherited
profile UserProfile?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supplierProfile SupplierProfile?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited